Retrieving PyPI Download Stats
------------------------------

* https://pepy.tech/project/bidict

* https://pypi.org/project/pypistats/

* https://packaging.python.org/en/latest/guides/analyzing-pypi-package-downloads/
